********************************************************************************
********************************************************************************
********************************************************************************
/*

Article: Using occupations to evaluate the employment effects of the German 
		  minimum wage
		  
Author:  Martin Friedrich (IAB)
Journal: Journal of Economics & Statisitcs

Note: 
This do-file aggregates the Integrated Employment Biographies to the level of
occupations. It generates the employment headcounts, which are the outcome 
variables of the empirical analysis of the paper.  

																			  */
																			  
********************************************************************************
********************************************************************************
********************************************************************************

clear all
set more off
set rmsg on

**** globals

global ieb  // this global has to be defined by the DIM-IT department of the IAB who are entitled to run the programme on the full IEB data

global ieb_bez // this global has to be defined by the DIM-IT department of the IAB who are entitled to run the programme on the full IEB data

global log // this global has to be defined by the DIM-IT department of the IAB who are entitled to run the programme on the full IEB data

global data // this global has to be defined by the DIM-IT department of the IAB who are entitled to run the programme on the full IEB data

global AMSNr // this global has to be defined by the DIM-IT department of the IAB who are entitled to run the programme on the full IEB data

***** Read IEB:
use prs_id ieb_beg_epi ieb_end_epi geb_dat ieb_quellverf_id wz08_kons_num ///
ieb_beruf_kons_num ow_knz ieb_erw_stat_num ieb_dba_id ieb_spell ///
berufstellg_imp_num ieb_tag_entg using $ieb\\$ieb_bez , clear

***** Open log-file

log using "$log\\${AMSNr}_logfile_`c(current_date)'.log", replace

*------------------------------------------------------------------------------*
*a.	CLEAN AND FILTER DATA 
*------------------------------------------------------------------------------*

***** Keep only observations from 2012q1 until 2019 
drop if ieb_end_epi<mdy(01,01,2012)
drop if ieb_beg_epi>=mdy(01,01,2019)

***** Keep only observations from BeH (no benefit recepients etc.)
keep if ieb_quellverf_id==1

***** Drop employees that are exempted from the minimum wage
*Agriculture & forestry
drop if wz08_kons_num < 3000
drop if ieb_beruf_kons_num < 11400
drop if ieb_beruf_kons_num >= 11500 & ieb_beruf_kons_num < 12200

*Gardening
drop if wz08_kons_num == 81301 | wz08_kons_num == 81309
drop if ieb_beruf_kons_num > 12100 & ieb_beruf_kons_num < 12200

*Meat industry
drop if wz08_kons_num == 10110 | wz08_kons_num == 10120 | wz08_kons_num == 10130 
drop if ieb_beruf_kons_num == 29232 | ieb_beruf_kons_num == 29233

*hair dressers
drop if wz08_kons_num == 96021
drop if ieb_beruf_kons_num == 82311 | ieb_beruf_kons_num == 82312

*temporary workers in East Germany
drop if (wz08_kons_num == 78200 | wz08_kons_num == 78300) & ow_knz==2

*laundry services
drop if wz08_kons_num == 96010
drop if ieb_beruf_kons_num == 54132

*textil industry
drop if wz08_kons_num > 13000 & wz08_kons_num < 16000
drop if ieb_beruf_kons_num > 28000 & ieb_beruf_kons_num < 29000

*Vocational training, interns, volunteers
drop if ieb_erw_stat_num == 102 | ieb_erw_stat_num == 105 | ieb_erw_stat_num == 121 | ieb_erw_stat_num == 122 | ieb_erw_stat_num == 123    

*Minors without a degree
cap drop year 
gen year = year(ieb_beg_epi)
cap drop birth_year 
gen birth_year = year(geb_dat)
format birth_year year %9.0g 
cap drop age
gen age = year - birth_year
drop if age < 18 & ieb_dba_id ==1

***** keep only regular and marginal employees 
cap drop empl_type
gen empl_type = . 
replace empl_type = 1 if ieb_erw_stat_num != . & ieb_erw_stat_num != 109 & ieb_erw_stat_num != 209 
replace empl_type = 2 if ieb_erw_stat_num == 109 | ieb_erw_stat_num==209 
lab var empl_type "type of employment (official class.)"
lab def empl_type 1"[1]regular employment" 2"[2]marginal employment"
lab val empl_type empl_type


***** Keep only relevant variables
keep prs_id ieb_beg_epi ieb_end_epi geb_dat ieb_beruf_kons_num ow_knz empl_type ieb_spell berufstellg_imp_num ieb_tag_entg

*------------------------------------------------------------------------------*
*b.	GENERATE AND LABEL VARIABLES 
*------------------------------------------------------------------------------*

***Year
gen year=year(ieb_beg_epi)
lab var year "calendar year"

***East- or West-Germany
rename ow_knz east
recode east 1=0 2=1
lab var east "East-Germany"
lab def east 0"[0]West" 1"[1]East"
lab val east east


***Full-time employment
cap drop empl_FT
gen empl_FT = .
replace empl_FT = 0 if berufstellg_imp_num == 21
replace empl_FT = 1 if berufstellg_imp_num == 20
drop berufstellg_imp_num

*****Rename and label variables
rename prs_id id
lab var id "id"

rename ieb_spell spell
lab var spell "spell identifier by person"

rename ieb_beg_epi spell_begin
lab var spell_begin "beginning of the spell" 

rename ieb_end_epi spell_end
lab var spell_end "end of the spell"

rename geb_dat birthdate
lab var birthdate "date of birth"

rename ieb_beruf_kons_num occupation_KldB2010
lab var occupation_KldB2010 "occupation according to KldB 2010"

rename ieb_tag_entg wage_day
lab var wage_day "daily wage"

lab var empl_FT "full-time/part-time empl"
lab def empl_FT 0"[0]part-time" 1"[1]full-time"
lab val empl_FT empl_FT


***drop duplicates 
*not sure where they are coming from
duplicates drop id spell_begin spell_end birthdate wage_day occupation_KldB2010 east empl_type year empl_FT, force


*------------------------------------------------------------------------------*
*b.	Transform data into quarterly panel data 
*------------------------------------------------------------------------------*

*****quarter variable
*number of months a spell spans over
gen byte span_month = (month(spell_end)-month(spell_begin)+1)


* number of duplicates to be created
cap drop span_quart
gen span_quart = 1 
replace span_quart = 2 if span_month > 3
replace span_quart = 3 if span_month > 6
replace span_quart = 4 if span_month > 9


*replicate observations that span over more than one quarter
expand span_quart
sort id year
duplicates tag id spell, gen(dupl)


cap drop counter
bysort id spell: gen counter = _n
replace counter = counter - 1 

cap drop beg_quarter
gen beg_quarter=.
bysort id spell : replace beg_quarter = 1 if month(spell_begin) < 4 
bysort id spell : replace beg_quarter = 2 if month(spell_begin) >= 4 & month(spell_begin) < 7 
bysort id spell : replace beg_quarter = 3 if month(spell_begin) >= 7 & month(spell_begin) < 10 
bysort id spell : replace beg_quarter = 4 if month(spell_begin) >= 10 & month(spell_begin) !=. 

cap drop quarter
gen quarter = beg_quarter + counter
drop beg_quarter counter


*****generating a quarter variable that is time-identifying
cap drop quarter_time_var
gen quarter_time_var = . 


*2012
forvalues i=1/4{
replace quarter_time_var = `i' if year == 2012 & quarter == `i'
}
*

*2013
forvalues i=1/4{
replace quarter_time_var = 4+`i' if year == 2013 & quarter == `i'
}
*

*2014
forvalues i=1/4{
replace quarter_time_var = 8+`i' if year == 2014 & quarter == `i'
}
*

*2015
forvalues i=1/4{
replace quarter_time_var = 12+`i' if year == 2015 & quarter == `i'
}
*

*2016
forvalues i=1/4{
replace quarter_time_var = 16+`i' if year == 2016 & quarter == `i'
}
*

*2017
forvalues i=1/4{
replace quarter_time_var = 20+`i' if year == 2017 & quarter == `i'
}
*

*label quarters
lab def quarter 1"[1]2012q1" 2"[2]2012q2" 3"[3]2012q3" 4"[4]2012q4" ///
				5"[5]2013q1" 6"[6]2013q2" 7"[7]2013q3" 8"[8]2013q4" ///
				9"[9]2014q1" 10"[10]2014q2" 11"[11]2014q3" 12"[12]2014q4" ///
				13"[13]2015q1" 14"[14]2015q2" 15"[15]2015q3" 16"[16]2015q4" ///
				17"[17]2016q1" 18"[18]2016q2" 19"[19]2016q3" 20"[20]2016q4" ///
				21"[21]2017q1" 22"[22]2017q2" 23"[23]2017q3" 24"[24]2017q4" /// 
				
lab val quarter_time_var quarter
tab quarter_time_var

*------------------------------------------------------------------------------*
*b.	Cleaning data to replicate official BA statistics  
*------------------------------------------------------------------------------*

******Keep only episodes that includes keydate ("Stichtag") for each quarter
gen keydate =.
replace keydate = mdy(3,31,year) if quarter == 1
replace keydate = mdy(6,30,year) if quarter == 2 
replace keydate = mdy(9,30,year) if quarter == 3
replace keydate = mdy(12,31,year) if quarter == 4  
format keydate %tdD_m_Y
keep if spell_begin <= keydate & spell_end >= keydate


*****BA Stat is about employees not jobs 
*I delete multiple jobs of the same kind held by the same person in any quarter
cap drop job_count
bysort id quarter_time_var empl_type : gen job_count = _n
drop if job_count > 1

keep id quarter_time_var occupation_KldB2010 empl_type empl_FT east

sort id quarter_time_var empl_type 
order id quarter_time_var occupation_KldB2010 empl_type empl_FT east 

*------------------------------------------------------------------------------*
*c.	Aggregate data to level of occupations 
*------------------------------------------------------------------------------*

***three plus 5 digit level
tostring occupation_KldB2010, gen(occupation_5)
drop occupation_KldB2010

gen str kldb_3 = substr(occupation_5,1,3)
gen str help1 = substr(occupation_5,5,5)

gen str kldb_3_5 = kldb_3 + help1
drop kldb_3
drop help1
drop occupation_5

***four-digit level
*tostring occupation_KldB2010, gen(occupation_5)
*gen str occupation_4 = substr(occupation_5,1,4)
*drop if occupation_4 == "-9"

***GERMANY***
*regular employment
preserve
collapse (count) id if empl_type == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg
lab var empl_reg "total of regular employment"
save $data\\${AMSNr}_empl_reg_GER.dta, replace
restore

*full-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_FT
lab var empl_reg_FT "total of full-time regular employment"
save $data\\${AMSNr}_empl_reg_FT_GER.dta, replace
restore

*part-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 0, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_PT
lab var empl_reg_PT "total of part-time regular employment"
save $data\\${AMSNr}_empl_reg_PT_GER.dta, replace
restore

*marginal employment
preserve
collapse (count) id if empl_type == 2, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_mar
lab var empl_mar "total of marginal employment"
save $data\\${AMSNr}_empl_mar_GER.dta, replace
restore



***EAST-GERMANY***
preserve
collapse (count) id if empl_type == 1 & east == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg
lab var empl_reg "total of regular employment"
save $data\\${AMSNr}_empl_reg_EAST.dta, replace
restore


*full-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 1 & east == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_FT
lab var empl_reg_FT "total of full-time regular employment"
save $data\\${AMSNr}_empl_reg_FT_EAST.dta, replace
restore

*part-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 0 & east == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_PT
lab var empl_reg_PT "total of part-time regular employment"
save $data\\${AMSNr}_empl_reg_PT_EAST.dta, replace
restore

*marginal employment
preserve
collapse (count) id if empl_type == 2 & east == 1, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_mar
lab var empl_mar "total of marginal employment"
save $data\\${AMSNr}_empl_mar_EAST.dta, replace
restore

***WEST-GERMANY***
preserve
collapse (count) id if empl_type == 1 & east == 0, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg
lab var empl_reg "total of regular employment"
save $data\\${AMSNr}_empl_reg_WEST.dta, replace
restore

*full-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 1 & east == 0, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_FT
lab var empl_reg_FT "total of full-time regular employment"
save $data\\${AMSNr}_empl_reg_FT_WEST.dta, replace
restore

*part-time regular employment
preserve
collapse (count) id if empl_type == 1 & empl_FT == 0 & east == 0, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_reg_PT
lab var empl_reg_PT "total of part-time regular employment"
save $data\\${AMSNr}_empl_reg_PT_WEST.dta, replace
restore

*marginal employment
preserve
collapse (count) id if empl_type == 2 & east == 0, by(kldb_3_5 quarter_time_var) 
order kldb_3_5 quarter_time_var id
*replace id = id * (1/0.02)
rename id empl_mar
lab var empl_mar "total of marginal employment"
save $data\\${AMSNr}_empl_mar_WEST.dta, replace
restore


*------------------------------------------------------------------------------*
*c.	End of the do-file
*------------------------------------------------------------------------------*

log close
clear all
exit
















