********************************************************************************
********************************************************************************
********************************************************************************
/*

Article: Using occupations to evaluate the employment effects of the German 
		  minimum wage
		  
Author:  Martin Friedrich (IAB)
Journal: Journal of Economics & Statisitcs

Note: 

This do-file calculates the bite of the minimum wage by occupation using the 
Structure of Earnings Survey of the Federal Statistical Office of Germany. 

																			  */
																			  
********************************************************************************
********************************************************************************
********************************************************************************

clear all

*** macros
global datenpfad // this is where the VSE micro data is stored
global outputpfad // this is your output destination on the FDZ computer
global do_files // this is where your do-files are stored on the FDZ computer

********************************************************************************************************************
********************************************************************************************************************
********** I. Preparation 
********************************************************************************************************************
********************************************************************************************************************


**** a. Read the data

use $datenpfad/GWAP_VSE2014_Arbeitnehmer_3750-2019, clear
 
***** b. Define the sample

***Identify employees that are exempted from the minimum wage

**ML_pers: assign a 1 to all workers
cap drop ML_1
gen ML_1 = 1
lab var ML_1 "person who is exempted from the minimum wage ML_1 == 0"

**coder workers to 0 who are expemted

*vocational training and interns
destring PERSONENGRUPPE, replace
replace ML_1 = 0 if (PERSONENGRUPPE == 102) | (PERSONENGRUPPE == 105) | (PERSONENGRUPPE == 113)  | (PERSONENGRUPPE == 114) | ///
					(PERSONENGRUPPE == 116) | (PERSONENGRUPPE == 121) | (PERSONENGRUPPE == 122) | (PERSONENGRUPPE == 124)  | (PERSONENGRUPPE == 141) | ///
					(PERSONENGRUPPE == 144) | (PERSONENGRUPPE == 801) | (PERSONENGRUPPE == 802) | (PERSONENGRUPPE == 803)  

*minors without a degree
replace ML_1 = 0 if EF59U3 == "1" &  EF41 < 18 

*agriculture and forestry
gen str wz08_2 = substr(EF4,1,2) 
replace ML_1 = 0 if wz08_2 == "01" | wz08_2 == "02" 

*gardening
gen str kldb_4 = substr(EF15,1,4)
replace ML_1 = 0 if kldb_4 == "1210" | kldb_4 == "1214" | kldb_4 == "1219"

*meat industry
gen str wz08_3 = substr(EF4,1,3) 
replace ML_1 = 0 if wz08_3 == "101" 

*temporary work in East Germany
destring EF4U1, replace
replace ML_1 = 0 if wz08_2 == "78" & EF4U1 >= 11 & EF4U1 != . 

*textil industry
replace ML_1 = 0 if wz08_2 == "13" | wz08_2 == "14" 

*hair dressers
replace ML_1 = 0 if kldb_4 == "8231" 

*laundry services 
replace ML_1 = 0 if kldb_4 == "5313" 

***drop people who are exempted
drop if ML_1 == 0
drop ML_1


********************************************************************************************************************
********************************************************************************************************************
********** II. Analysis 
********************************************************************************************************************
********************************************************************************************************************


*****1) Generate the bite of the minimum wage

***occupations are on the three + five digit level

gen str kldb_3 = substr(EF15,1,3)
*tab kldb_3 

gen str help1 = substr(EF15,5,5)
tab help1 

gen str kldb_3_5 = kldb_3 + help1
*tab kldb_3_5 
*browse EF15 kldb_3_5

*The lables of the variables below are in German because that is what the employees of the FDZ prefer.
*They have to check whether the output complies with their confidentiality regulations.

preserve
	collapse (mean) bite = unterML (semean) se_bite = unterML (count) N_gw = unterML (sum) N_1_gw = unterML N_0_gw = ueberML [fweight = round(B52,1)], by(kldb_3_5)
	gen KI_UG = bite - 1.96*se_bite
	gen KI_OG = bite + 1.96*se_bite
	lab var bite "Anteil von Arbeitnehmern die 2014 unter 8.50/h verdienten"
	lab var se_bite "Standardfehler des bite"
	lab var N_gw "Fallzahl insgesamt gewichtet"
	lab var N_0_gw "Fallzahl fuer bite == 0 gewichtet"
	lab var N_1_gw "Fallzahl fuer bite == 1 gewichtet"
	lab var KI_UG "Konfidenzinterval bite Untergrenze"
	lab var KI_OG "Konfidenzinterval bite Obergrenze"
	order kldb_3_5 bite se_bite KI_UG KI_OG N_gw N_0_gw N_1_gw
	save "$outputpfad\bite_kldb_3_5_gw.dta", replace
restore

preserve
	collapse (count) N_ug = unterML (sum) N_1_ug = unterML N_0_ug = ueberML , by(kldb_3_5)
	lab var N_ug "Fallzahl insgesamt ungewichtet"
	lab var N_0_ug "Fallzahl fuer bite == 0 ungewichtet"
	lab var N_1_ug "Fallzahl fuer bite == 1 ungewichtet"
	order kldb_3_5 N_ug N_0_ug N_1_ug
	save "$outputpfad\bite_kldb_3_5_ug.dta", replace
restore

preserve
	use "$outputpfad\bite_kldb_3_5_gw.dta", clear
	merge 1:1 kldb_3_5 using "$outputpfad\bite_kldb_3_5_ug.dta", nogen 
	lab var kldb_3_5 "Klassifikation der Berufe 2010 3 + 5 Steller"
	
	***drop cells with less than 20 employees that facotred into the calculation
	drop if N_ug < 20
	
	save  "$outputpfad\bite_kldb_3_5.dta", replace
	erase "$outputpfad\bite_kldb_3_5_gw.dta"
	erase "$outputpfad\bite_kldb_3_5_ug.dta"
restore




