********************************************************************************
********************************************************************************
********************************************************************************
/*

Article: Using occupations to evaluate the employment effects of the German 
		  minimum wage
		  
Author:  Martin Friedrich (IAB)
Journal: Journal of Economics & Statisitcs

Note: 
This file links the aggregated data of the IEB and VSE. Also, some recoding 
takes place in preparation of the analysis. 
																			  */
																			  
********************************************************************************
********************************************************************************
********************************************************************************

clear all
set more off

global ieb_aggr  // enter the place where the aggreagated IEB date are stored here (output of replication file #1)
global vse 		 // enter the place where the aggregated VSE date are  stored here (output of replication file #2)
global ieb_vse_linked //this is the destination of the final linked data set
global data_temp //this is a folder for some auxilliary data

foreach x in GER WEST EAST{

//////merge the data
***merge employment data 
use $ieb_aggr\014695_empl_reg_`x'.dta, clear
merge 1:1 kldb_3_5 quarter_time_var using $ieb_aggr\014695_empl_mar_`x'.dta, nogen

***merge bite
merge m:1 kldb_3_5 using $vse\bite_kldb_3_5_final.dta
drop if _merge == 2
drop _merge

***merge median and mean hourly wage
merge m:1 kldb_3_5 using $vse\stdlohn_kldb_3_5_final.dta
drop if _merge == 2
drop _merge

//////code the data

***log employment
gen log_empl_reg = ln(empl_reg)
gen log_empl_mar = ln(empl_mar)

***skill level
tostring kldb_3_5, gen(kldb_str)
gen str skill_level = substr(kldb_str,4,4)
destring skill_level, replace


***recode bite
replace bite = 100*bite
sum bite
gen bite_for_desc = bite
replace bite = bite / r(sd)
lab var bite "share of workers affected by minimum wage reform"

*calculate the kaitz index and normalise it 
gen kaitz_median = 8.50/median_stdlohn
gen kaitz_mean = 8.50/mean_stdlohn

lab var kaitz_median "Kaitz index based on median hourly wage"
lab var kaitz_mean "Kaitz index based on mean hourly wage"
lab var median_stdlohn "median hourly wage"
lab var mean_stdlohn "mean hourly wage"

gen kaitz = 100*kaitz_median
sum kaitz
replace kaitz = kaitz / r(sd)
lab var kaitz "kaitz index normalised for the regression analysis"

***year dummies
cap drop year
gen year=.
replace year=1 if quarter_time_var <= 4
replace year=2 if quarter_time_var >= 5 & quarter_time_var < 9
replace year=3 if quarter_time_var >= 9 & quarter_time_var < 13
replace year=4 if quarter_time_var >= 13 & quarter_time_var < 17
replace year=5 if quarter_time_var >= 17 & quarter_time_var < 21
replace year=6 if quarter_time_var >= 21 & quarter_time_var !=.
tab year

lab var year "year-dummies"
lab def year 1"[1]2012" 2"[2]2013" 3"[3]2014" 4"[4]2015" 5"[5]2016" 6"[6]2017"
lab val year year
tab year

***create season FE
gen season = 1 if quarter_time_var == 1 | quarter_time_var == 5 | quarter_time_var == 9 | quarter_time_var == 13 | quarter_time_var == 17 | quarter_time_var == 21 
replace season = 2 if quarter_time_var == 2 | quarter_time_var == 6 | quarter_time_var == 10 | quarter_time_var == 14 | quarter_time_var == 18 | quarter_time_var == 22 
replace season = 3 if quarter_time_var == 3 | quarter_time_var == 7 | quarter_time_var == 11 | quarter_time_var == 15 | quarter_time_var == 19 | quarter_time_var == 23 
replace season = 4 if quarter_time_var == 4 | quarter_time_var == 8 | quarter_time_var == 12 | quarter_time_var == 16 | quarter_time_var == 20 | quarter_time_var == 24 


***non-linear trend variables
cap drop trend1
gen trend1 = quarter_time_var / 10
lab var trend1 "linear time trend"

cap drop trend2
gen trend2 = quarter_time_var^2 / 100
lab var trend2 "quadratic time trend"

cap drop trend3
gen trend3 = quarter_time_var^3 / 1000
lab var trend3 "cubic time trend"

cap drop trend4
gen trend4 = quarter_time_var^4 / 10000
lab var trend4 "quartic time trend"

cap drop trend5
gen trend5 = quarter_time_var^5 / 100000
lab var trend5 "qunitic time trend"

cap drop trend6
gen trend6 = quarter_time_var^6
lab var trend6 "sextic time trend"


cap drop trend7
gen trend7 = quarter_time_var^7
lab var trend7 "septic time trend"

cap drop trend8
gen trend8 = quarter_time_var^8
lab var trend8 "octic time trend"
*/

cap drop log_trend
gen log_trend = log(quarter_time_var)
lab var log_trend "log time trend"


forvalues i=1/8{

gen bite_trend`i' = bite * trend`i'
lab var bite_trend`i' "bite proportional trend order `i'"

}
*

***rename occupation
rename kldb_3_5 occ

***merge labels for occupations
gen str kldb_3 = substr(kldb_str,1,3)
destring kldb_3, replace
merge m:1 kldb_3 using $data_temp/kldb_3_labels.dta
drop if _merge == 2
drop _merge

gen str label_5 = "Helfer" if skill_level == 1 
replace  label_5 = "Fachkraft" if skill_level == 2 
replace  label_5 = "Spezialist" if skill_level == 3
replace  label_5 = "Experte" if skill_level == 4 

***labels

lab var occ "occupation 3+5 digit"
lab var kldb_3 "occupation 3 digit"
lab var skill_level "task complexity"
lab var label_3 "label 3rd digit"
lab var label_5 "label 5th digit"
lab var log_empl_reg "log of regular employment"
lab var log_empl_mar "log of marginal employment"
lab var quarter_time_var "running quarterly time variable"
lab var season "season FE"
lab var bite_for_desc "bite on original scale"
lab var auto_for_desc "automation probability on original scale"

drop kldb_str kldb_3

order occ label_3 label_5 quarter_time_var year season empl_reg empl_mar log_empl_reg log_empl_mar bite kaitz_median kaitz_mean skill_level  median_stdlohn mean_stdlohn

save $ieb_vse_linked/IEB_VSE_linked_`x'_3_5digit.dta, replace

}
*







