********************************************************************************
********************************************************************************
********************************************************************************
/*

Article: Using occupations to evaluate the employment effects of the German 
		  minimum wage
		  
Author:  Martin Friedrich (IAB)
Journal: Journal of Economics & Statisitcs

Note: 
This do-file creates all tables and graphs that are included in the article.
It requires installation of the parmest package.  

																			  */
********************************************************************************
********************************************************************************
********************************************************************************

**********0) Settings

clear all
set more off
set seed 4920173
adopath ++ N:\Ablagen\D01700-Allgemein\STATA\bocode 

**********1) Define macros

global ieb_vse_linked // folder where the linked IEB-VSE data are stored (output of replication file #3)

global data_temp //folder to store auxilliary data 

global tables // folder to export the tables

global graphs // folder to export the graphs


**********2) Create tables for the main body

***** Table 1: Total employment by region in June 2014

foreach x in GER WEST EAST{

use ${ieb_vse_linked}\IEB_VSE_linked_`x'_3_5digit.dta, clear

preserve
collapse (sum) empl_reg empl_mar if quarter_time_var == 10 & bite !=.
rename empl_reg reg_without_MVbite
rename empl_mar mar_without_MVbite
gen str region = "`x'"
save ${data_temp}\total_MVbite_`x', replace
restore
}
*

use ${data_temp}\total_MVbite_GER , clear
merge 1:1 region using ${data_temp}\total_MVbite_WEST, nogen update
merge 1:1 region using ${data_temp}\total_MVbite_EAST, nogen update

order region  reg_without_MVbite  mar_without_MVbite 
export excel using ${tables}/Table_1.xls, replace firstrow(var)

erase ${data_temp}\total_MVbite_GER.dta
erase ${data_temp}\total_MVbite_WEST.dta
erase ${data_temp}\total_MVbite_EAST.dta


***** Table 2: Summary statistics of the bite of the minimum wage and Kaitz index 

use ${ieb_vse_linked}\IEB_VSE_linked_GER_3_5digit.dta, clear

/*Only keep the 2014q2 measurment becomes these variable come from the VSE and 
  there is no longitudinal variation */

keep if quarter_time_var == 10 

/* Use the same occupations to summarise the Kaitz and bite indices because 
   the regressions are later run on this sample as well	*/

replace kaitz_median = . if bite_for_desc == .  
sum bite_for_desc kaitz_median

drop bite
rename bite_for_desc bite
drop kaitz
rename kaitz_median kaitz

collapse (mean) mean_bite = bite mean_kaitz = kaitz (p50) median_bite = bite median_kaitz = kaitz ///
(sd) sd_bite = bite sd_kaitz = kaitz (min) min_bite = bite  min_kaitz = kaitz ///
(max) max_bite = bite max_kaitz = kaitz  (count) N_bite = bite N_kaitz = kaitz
order *bite *kaitz

export excel using ${tables}/Table_2.xls, replace firstrow(var)


**********3) Create figures for the main body

***** Figure 1: Frequency of occupations by the bite of the minimum wage

use ${ieb_vse_linked}\IEB_VSE_linked_GER_3_5digit.dta, clear
collapse bite_for_desc, by(occ)
rename bite_for_desc bite
drop if bite == . 

cap drop bite_cut
gen bite_cut = .
replace bite_cut = 1 if bite <= 0.5
replace bite_cut = 2 if bite > 0.5 & bite <=5
replace bite_cut = 3 if bite > 5 & bite <= 10
replace bite_cut = 4 if bite > 10 & bite <= 15
replace bite_cut = 5 if bite > 15 & bite <= 20
replace bite_cut = 6 if bite > 20 & bite <= 30
replace bite_cut = 7 if bite > 30 & bite !=.
tab bite_cut 

collapse (count) occ, by(bite_cut)
rename occ freq
rename bite_cut bite_cat

lab def bite_cat 1"0-0.5" 2"0.6-5.0" 3"5.1-10.0" 4"10.1-15.0" 5"15.1-20.0" 6"20.1-30.0" 7"30.1-86.0"
lab val bite_cat bite_cat

graph bar  freq , over(bite_cat) ///
bar(1, fcolor(gs10) lcolor(black)) ytitle("frequency of occupations") blabel(bar) ///
legend(off) b1title("bite of the minimum wage in percent") graphregion(fcolor(white)) bgcolor(white)

graph export ${graphs}\Figure_1.pdf , replace


***** Data preparation for Figure 2 & Figure 3

use ${ieb_vse_linked}\IEB_VSE_linked_GER_3_5digit.dta, clear
sum bite_for_desc, d
gen bite_cat=.
replace bite_cat = 1 if bite_for_desc < `r(p50)' 
replace bite_cat = 2 if bite_for_desc >= `r(p50)' & bite!=.
tab bite_cat

collapse (sum) empl_reg empl_mar if bite!=. , by(quarter_time_var bite_cat)

gen season = 1 if quarter_time_var == 1 | quarter_time_var == 5 | quarter_time_var == 9 | quarter_time_var == 13 | quarter_time_var == 17 | quarter_time_var == 21 
replace season = 2 if quarter_time_var == 2 | quarter_time_var == 6 | quarter_time_var == 10 | quarter_time_var == 14 | quarter_time_var == 18 | quarter_time_var == 22 
replace season = 3 if quarter_time_var == 3 | quarter_time_var == 7 | quarter_time_var == 11 | quarter_time_var == 15 | quarter_time_var == 19 | quarter_time_var == 23 
replace season = 4 if quarter_time_var == 4 | quarter_time_var == 8 | quarter_time_var == 12 | quarter_time_var == 16 | quarter_time_var == 20 | quarter_time_var == 24 

***sesonal adjustment
reg empl_reg quarter_time_var 
predict empl_reg_trend
gen empl_reg_resid = empl_reg - empl_reg_trend
bysort bite_cat season: egen mean_resid_reg = mean(empl_reg_resid)
gen empl_reg_adj = empl_reg - mean_resid_reg

reg empl_mar quarter_time_var 
predict empl_mar_trend
gen empl_mar_resid = empl_mar - empl_mar_trend
bysort bite_cat season: egen mean_resid_mar = mean(empl_mar_resid)
gen empl_mar_adj = empl_mar - mean_resid_mar

sort bite_cat quarter_time_var

***code growth variables
bysort bite_cat(quarter_time_var): gen growth_reg = (empl_reg_adj/empl_reg_adj[1]) *100
bysort bite_cat(quarter_time_var): gen growth_mar = (empl_mar_adj/empl_mar_adj[1]) *100

***** Figure 2: Growth of regular employment by the bite of the minimum wage

twoway connected growth_reg quarter if bite_cat==1, xlabel(1"2012" 4"2013" 8"2014" 12"2015" 16"2016" 20"2017" 24"2018", labgap (*3)) ///
				xmlabel(1"q2" 2"q3" 3"q4" 4"q1" 5"q2" 6"q3" 7"q4" 8"q1" 9"q2" 10"q3" 11"q4" 12"q1" 13"q2" 14"q3" 15"q4" 16"q1" 17"q2" 18"q3" 19"q4" 20"q1" 21"q2" 22"q3" 23"q4" 24"q1") ///
				xtitle("") scheme( s2mono ) ytitle("percentage change") ylabel(100(2)116) ///
                xline(12, lwidth(0.1)) text(114 12 "minimum wage" "becomes" "effective", box size(small)) ///
				xline(20, lwidth(0.1)) text(102 20 "minimum wage" "is increased", box size(small)) ///
				legend(label(1 "weakly treated") label(2 "strongly treated")) msize(medium) lpattern(dash) lcolor(blue) mcolor(blue) ///
				|| connected growth_reg quarter if bite_cat==2, msize(medium) msymbol(triangle) lcolor(blue) mcolor(blue)  graphregion(fcolor(white))  bgcolor(white)

graph export ${graphs}\Figure_2.pdf,  replace
graph export ${graphs}\Figure_2.png, width(1200)  replace

***** Figure 3: Growth of marginal employment by the bite of the minimum wage

twoway connected growth_mar quarter if bite_cat==1, xlabel(1"2012" 4"2013" 8"2014" 12"2015" 16"2016" 20"2017" 24"2018", labgap (*3)) ///
				xmlabel(1"q2" 2"q3" 3"q4" 4"q1" 5"q2" 6"q3" 7"q4" 8"q1" 9"q2" 10"q3" 11"q4" 12"q1" 13"q2" 14"q3" 15"q4" 16"q1" 17"q2" 18"q3" 19"q4" 20"q1" 21"q2" 22"q3" 23"q4" 24"q1") ///
				xtitle("") scheme( s2mono ) ytitle("percentage change") ylabel(90(2)102) ///
                xline(12, lwidth(0.1)) text(92 12 "minimum wage" "becomes" "effective", box size(small)) ///
				xline(20, lwidth(0.1)) text(98 20 "minimum wage" "is increased", box size(small)) ///
				legend(label(1 "weakly treated") label(2 "strongly treated")) msize(medium) lpattern(dash) lcolor(red) mcolor(red) ///
				|| connected growth_mar quarter if bite_cat==2, msize(medium) msymbol(triangle) lcolor(red) mcolor(red)  graphregion(fcolor(white)) bgcolor(white)

graph export ${graphs}\Figure_3.pdf,  replace
graph export ${graphs}\Figure_3.png, width(1200)  replace

/**** Figure 4: Regression estimates of the effect of the minimum wage on log
				regular employment in Germany (baseline estimates and underlying trend) 

	  Figure 5: Regression estimates of the effect of the minimum wage on log
				marginal employment in Germany (baseline estimates and underlying trend) 		*/
				
foreach x in GER{

use ${ieb_vse_linked}\IEB_VSE_linked_`x'_3_5digit.dta, clear
xtset occ quarter_time_var
*drop last period before reform to preclude anticipation effect (threat to idenitification)
drop if quarter_time_var == 12

*****************ESTIMATING THE MODELS*****************

*****1) Baseline model

***regular employment

xtreg log_empl_reg c.bite##ib3.year i.season, fe cluster(occ)

preserve

parmest, norestore

keep parm estimate min95 max95
gen year = _n + 2004
keep if year > 2011 & year < 2018
order parm year estimate min95 max95 

reg estimate year if year < 2015
predict trend, xb

gen trend2 = trend
replace trend = . if year > 2014
replace trend2 = . if year < 2014

gen estimate_detrended = estimate - trend
gen min95_detrend = min95 - trend
gen max95_detrend = max95 - trend

gen label_1 = round(estimate,0.001)

***baseline estimates and trend
twoway scatter estimate year, lcolor(blue) mcolor(blue) legend(label(1 "baseline estimates")) ///
 ytitle("")  xtitle("") xline(2014.5) mlabel(label_1)  mlabposition(9)  || rcap min95 max95 year, lcolor(blue) mcolor(blue) legend(label(2 "95% CI")) ///
 || line trend year,   lcolor(green)  legend(label(3 "trend estimate")) || line trend2 year, lpattern(dash)  lcolor(green) legend(label(4 "trend extrapolation")) ///
 graphregion(fcolor(white)) bgcolor(white)

graph export ${graphs}\Figure_4.pdf,  replace
graph export ${graphs}\Figure_4.png, width(1200)  replace

restore

***marginal employment

xtreg log_empl_mar c.bite##ib3.year i.season, fe cluster(occ)

preserve

parmest, norestore

keep parm estimate min95 max95
gen year = _n + 2004
keep if year > 2011 & year < 2018
order parm year estimate min95 max95 

reg estimate year if year < 2015
predict trend, xb

gen trend2 = trend
replace trend = . if year > 2014
replace trend2 = . if year < 2014

gen estimate_detrended = estimate - trend
gen min95_detrend = min95 - trend
gen max95_detrend = max95 - trend

gen label_1 = round(estimate,0.001)

***baseline estimates and trend
twoway scatter estimate year, lcolor(red)  ms(triangle) mcolor(red) legend(label(1 "baseline estimates")) ///
 ytitle("")  xtitle("") xline(2014.5) mlabel(label_1)  mlabposition(9)  || rcap min95 max95 year, lcolor(red) msymbol(triangle) mcolor(red) legend(label(2 "95% CI")) ///
 || line trend year,   lcolor(green)  legend(label(3 "trend estimate")) || line trend2 year, lpattern(dash)  lcolor(green) legend(label(4 "trend extrapolation")) ///
 graphregion(fcolor(white)) bgcolor(white)
 
graph export ${graphs}\Figure_5.pdf,  replace
graph export ${graphs}\Figure_5.png, width(1200)  replace

restore
}



/**** Figure 6: De-trended regression estimates of the effect of the minimum wage on log employment in Germany 
			
	  Figure 7: De-trended regression estimates of the effect of the minimum wage on log employment in West Germany 
	  		
	  Figure 8: De-trended regression estimates of the effect of the minimum wage on log employment in East Germany  */
				

foreach x in GER WEST EAST{

use ${ieb_vse_linked}\IEB_VSE_linked_`x'_3_5digit.dta, clear
xtset occ quarter_time_var
*drop last period before reform to preclude anticipation effect (threat to idenitification)
drop if quarter_time_var == 12

***** Baseline model

foreach y in reg mar {

xtreg log_empl_`y' c.bite##ib3.year i.season, fe cluster(occ)

preserve

parmest, norestore

keep parm estimate min95 max95
gen year = _n + 2004
keep if year > 2011 & year < 2018
order parm year estimate min95 max95 

reg estimate year if year < 2015
predict trend, xb

gen estimate_detrended_`y' = estimate - trend
gen min95_detrend_`y' = min95 - trend
gen max95_detrend_`y' = max95 - trend

keep year estimate_detrended_`y'  min95_detrend_`y' max95_detrend_`y'

save ${data_temp}\coefficients_`y'_`x'.dta, replace 
restore

}
}
*

foreach x in GER WEST EAST{

use ${data_temp}\coefficients_reg_`x'.dta, clear
merge 1:1 year using ${data_temp}\coefficients_mar_`x'.dta, nogen

reshape long estimate_detrended_  min95_detrend_ max95_detrend_, i(year) j(empl) string

clonevar x = year

replace x = cond(empl=="reg", x - 0.1, x + 0.1)

gen label_1 = round(estimate_detrended_,0.001) if year > 2014

twoway scatter estimate_detrended_ x if empl == "reg" , lcolor(blue) mcolor(blue) legend(label(1 "regular employment")) ///
 ytitle("")  xtitle("") xline(2014.5) yline(0, lpattern(dash) lcolor(red))  mlabel(label_1)  mlabposition(9) ///
 || rcap min95_detrend_ max95_detrend_ x if empl == "reg", lcolor(blue) mcolor(blue) legend(label(2 "95% CI")) ///
 ||scatter estimate_detrended_ x if empl == "mar" , lcolor(red) mcolor(red) ms(triangle) legend(label(3 "marginal employment")) ///
 ytitle("")  xtitle("") xline(2014.5) yline(0, lpattern(dash) lcolor(green))  mlabel(label_1)  mlabposition(9) ///
 || rcap min95_detrend_ max95_detrend_ x if empl == "mar", lcolor(red) mcolor(red) legend(label(4 "95% CI")) ///
 graphregion(fcolor(white)) bgcolor(white)

if "`x'" == "GER"{

graph export ${graphs}\Figure_6.pdf,  replace

} 

if "`x'" == "WEST"{

graph export ${graphs}\Figure_7.pdf,  replace

} 

if "`x'" == "EAST"{

graph export ${graphs}\Figure_8.pdf,  replace

} 
}
* 

**********4) Create figures for the Appendix

/***** Figure A1: De-trended regression estimates of the effect of the Kaitz index
	              on employment in West Germany 
				  
		Figure A2: De-trended regression estimates of the effect of the Kaitz index
	               on employment in East Germany  		   */
				  

foreach x in WEST EAST{

use ${ieb_vse_linked}\IEB_VSE_linked_`x'_3_5digit.dta, clear
xtset occ quarter_time_var
*drop last period before reform to preclude anticipation effect (threat to idenitification)
drop if quarter_time_var == 12

*****1) Baseline model

foreach y in reg mar {

xtreg log_empl_`y' c.kaitz##ib3.year i.season, fe cluster(occ)

preserve

parmest, norestore

keep parm estimate min95 max95
gen year = _n + 2004
keep if year > 2011 & year < 2018
order parm year estimate min95 max95 

reg estimate year if year < 2015
predict trend, xb

gen estimate_detrended_`y' = estimate - trend
gen min95_detrend_`y' = min95 - trend
gen max95_detrend_`y' = max95 - trend

keep year estimate_detrended_`y'  min95_detrend_`y' max95_detrend_`y'

save ${data_temp}\coefficients_`y'_`x'.dta, replace 
restore

}
}
*

foreach x in WEST EAST{

use ${data_temp}\coefficients_reg_`x'.dta, clear
merge 1:1 year using ${data_temp}\coefficients_mar_`x'.dta, nogen

reshape long estimate_detrended_  min95_detrend_ max95_detrend_, i(year) j(empl) string

clonevar x = year

replace x = cond(empl=="reg", x - 0.1, x + 0.1)

gen label_1 = round(estimate_detrended_,0.001) if year > 2014

twoway scatter estimate_detrended_ x if empl == "reg" , lcolor(blue) mcolor(blue) legend(label(1 "regular employment")) ///
 ytitle("")  xtitle("") xline(2014.5) yline(0, lpattern(dash) lcolor(red))  mlabel(label_1)  mlabposition(9) ///
 || rcap min95_detrend_ max95_detrend_ x if empl == "reg", lcolor(blue) mcolor(blue) legend(label(2 "95% CI")) ///
 ||scatter estimate_detrended_ x if empl == "mar" , lcolor(red) mcolor(red) ms(triangle) legend(label(3 "marginal employment")) ///
 ytitle("")  xtitle("") xline(2014.5) yline(0, lpattern(dash) lcolor(green))  mlabel(label_1)  mlabposition(9) ///
 || rcap min95_detrend_ max95_detrend_ x if empl == "mar", lcolor(red) mcolor(red) legend(label(4 "95% CI")) ///
 graphregion(fcolor(white)) bgcolor(white)

 
if "`x'" == "WEST"{

graph export ${graphs}\Figure_A1.pdf,  replace

} 

if "`x'" == "EAST"{

graph export ${graphs}\Figure_A2.pdf,  replace

}
}
* 


/**** Figure A3: Regression estimates of the effect of the minimum wage on 
				 regular employment in Germany (baseline estimates and quadratic trend estimate) */

use ${ieb_vse_linked}\IEB_VSE_linked_GER_3_5digit.dta, clear
xtset occ quarter_time_var
*drop last period before reform to preclude anticipation effect (threat to idenitification)
*drop if quarter_time_var == 12

foreach y in reg {

*The var need to be called year so I can integrate it in the coefficient plot with the trend-adjusted models
xtreg log_empl_`y' c.bite##ib10.quarter_time_var, fe cluster(occ)

preserve

parmest, norestore

keep parm estimate min95 max95
keep if _n > 25 & _n < 50

order parm estimate min95 max95 

gen time = _n

reg estimate c.time##c.time if time < 10
predict trend, xb

gen estimate_detrended = estimate - trend
gen min95_detrend = min95 - trend
gen max95_detrend = max95 - trend

***baseline estimates and trend
gen label_1 = round(estimate,0.001)

twoway scatter estimate time, lcolor(blue) mcolor(blue) legend(label(1 "baseline estimates")) ///
 ytitle("")  xtitle("") xline(11.5)   || rcap min95 max95 time, lcolor(blue) mcolor(blue) legend(label(2 "95% CI")) ///
 || line trend time, lpattern(dash)  lcolor(green) legend(label(3 "quadratic trend estimate")) ///
 graphregion(fcolor(white)) bgcolor(white) ///
 xlabel(1"2012" 4"2013" 8"2014" 12"2015" 16"2016" 20"2017" 24"2018", labgap (*3)) ///
xmlabel(1"q2" 2"q3" 3"q4" 4"q1" 5"q2" 6"q3" 7"q4" 8"q1" 9"q2" 10"q3" 11"q4" 12"q1" 13"q2" 14"q3" 15"q4" 16"q1" 17"q2" 18"q3" 19"q4" 20"q1" 21"q2" 22"q3" 23"q4" 24"q1")

graph export ${graphs}\Figure_A3.pdf,  replace
graph export ${graphs}\Figure_A3.png, width(1000)  replace

}



